@@ -1,9 +1,9 @@
 #Workhorse Function for the STM model
-#compared to the original we have more initializations, 
+#compared to the original we have more initializations,
 # more explicit options, trimmed fat, memoization
 
 stm.control <- function(documents, vocab, settings, model=NULL) {
-  
+
   globaltime <- proc.time()
   verbose <- settings$verbose
   ##########
@@ -11,7 +11,11 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
   ##########
   ngroups <- settings$ngroups
   if(is.null(model)) {
-    if(verbose) cat("Beginning Initialization.\n")
+    if(verbose) cat(switch(EXPR=settings$init$mode,
+                           Spectral = "Beginning Spectral Initialization \n",
+                           LDA = "Beginning LDA Initialization \n",
+                           Random = "Beginning Random Initialization \n",
+                           Custom = "Beginning Custom Initialization \n"))
     #initialize
     model <- stm.init(documents, settings)
     #if we were using the Lee and Mimno method of setting K, update the settings
@@ -22,7 +26,7 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
     beta <- list(beta=model$beta)
     if(!is.null(model$kappa)) beta$kappa <- model$kappa
     lambda <- model$lambda
-    convergence <- NULL 
+    convergence <- NULL
     #discard the old object
     rm(model)
   } else {
@@ -38,32 +42,39 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
     convergence$stopits <- FALSE
     convergence$converged <- FALSE
     #iterate by 1 as that would have happened otherwise
-    convergence$its <- convergence$its + 1 
-  }    
-  
+    convergence$its <- convergence$its + 1
+  }
+
   #Pull out some book keeping elements
   ntokens <- sum(settings$dim$wcounts$x)
   betaindex <- settings$covariates$betaindex
   stopits <- FALSE
   if(ngroups!=1) {
-    groups <- cut(1:length(documents), breaks=ngroups, labels=FALSE) 
+    # randomly assign groups so that subsample are representative
+    groups <- split(seq_len(documents),
+                    sample(rep(seq_len(ngroups), length(documents))))
   }
   suffstats <- vector(mode="list", length=ngroups)
-  
+
+  if(settings$convergence$max.em.its==0) {
+    stopits <- TRUE
+    if(verbose) cat("Returning Initialization.")
+  }
   ############
   #Step 2: Run EM
   ############
   while(!stopits) {
-    
+
     #one set of updates with groups, another without.
     if(ngroups!=1) {
       #####
       #Blocked Updates
       #####
-      for(i in 1:ngroups) {
+      # ordering of groups should be randomized
+      for(i in sample(seq_len(ngroups))) {
         t1 <- proc.time()
         #update the group id
-        gindex <- which(groups==i)
+        gindex <- groups[[i]]
         #construct the group specific sets
         gdocs <- documents[gindex]
         if(is.null(mu$gamma)) {
@@ -73,18 +84,18 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
         }
         gbetaindex <- betaindex[gindex]
         glambda <- lambda[gindex,]
-        
+
         #run the model
-        suffstats[[i]] <- estep(documents=gdocs, beta.index=gbetaindex, 
-                                update.mu=(!is.null(mu$gamma)),  
-                                beta$beta, glambda, gmu, sigma, 
+        suffstats[[i]] <- estep(documents=gdocs, beta.index=gbetaindex,
+                                update.mu=(!is.null(mu$gamma)),
+                                beta$beta, glambda, gmu, sigma,
                                 verbose)
         if(verbose) {
           msg <- sprintf("Completed Group %i E-Step (%d seconds). \n", i, floor((proc.time()-t1)[3]))
           cat(msg)
         }
         t1 <- proc.time()
-        
+
         #if all slots are full.  Combine and run M-step
         if(!any(unlist(lapply(suffstats, is.null)))) {
           #Combine the sufficient statistics
@@ -103,19 +114,19 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
             bound.ss <- c(bound.ss, suffstats[[j]]$bound)
           }
           # Now do the updates themselves
-          mu <- opt.mu(lambda=lambda, mode=settings$gamma$mode, 
+          mu <- opt.mu(lambda=lambda, mode=settings$gamma$mode,
                        covar=settings$covariates$X, enet=settings$gamma$enet, ic.k=settings$gamma$ic.k,
                        maxits=settings$gamma$maxits)
-          sigma <- opt.sigma(nu=sigma.ss, lambda=lambda, 
+          sigma <- opt.sigma(nu=sigma.ss, lambda=lambda,
                              mu=mu$mu, sigprior=settings$sigma$prior)
           beta <- opt.beta(beta.ss, beta$kappa, settings)
- 
+
           if(verbose) {
            #M-step message
             timer <- floor((proc.time()-t1)[3])
-            msg <- ifelse(timer>1, 
+            msg <- ifelse(timer>1,
                           sprintf("Completed M-Step (%d seconds). \n", floor((proc.time()-t1)[3])),
-                          "Completed M-Step. \n") 
+                          "Completed M-Step. \n")
             cat(msg)
           }
         }
@@ -126,9 +137,9 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
       #####
       t1 <- proc.time()
       #run the model
-      suffstats <- estep(documents=documents, beta.index=betaindex, 
-                              update.mu=(!is.null(mu$gamma)),  
-                              beta$beta, lambda, mu$mu, sigma, 
+      suffstats <- estep(documents=documents, beta.index=betaindex,
+                              update.mu=(!is.null(mu$gamma)),
+                              beta$beta, lambda, mu$mu, sigma,
                               verbose)
       msg <- sprintf("Completed E-Step (%d seconds). \n", floor((proc.time()-t1)[3]))
       if(verbose) cat(msg)
@@ -138,17 +149,17 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
       beta.ss <- suffstats$beta
       bound.ss <- suffstats$bound
       #do the m-step
-      mu <- opt.mu(lambda=lambda, mode=settings$gamma$mode, 
+      mu <- opt.mu(lambda=lambda, mode=settings$gamma$mode,
                    covar=settings$covariates$X, enet=settings$gamma$enet, ic.k=settings$gamma$ic.k,
                    maxits=settings$gamma$maxits)
-      sigma <- opt.sigma(nu=sigma.ss, lambda=lambda, 
+      sigma <- opt.sigma(nu=sigma.ss, lambda=lambda,
                          mu=mu$mu, sigprior=settings$sigma$prior)
       beta <- opt.beta(beta.ss, beta$kappa, settings)
       if(verbose) {
         timer <- floor((proc.time()-t1)[3])
-        msg <- ifelse(timer>1, 
+        msg <- ifelse(timer>1,
                       sprintf("Completed M-Step (%d seconds). \n", floor((proc.time()-t1)[3])),
-                      "Completed M-Step. \n") 
+                      "Completed M-Step. \n")
         cat(msg)
       }
     }
@@ -157,7 +168,7 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
     stopits <- convergence$stopits
 
     #Print Updates if we haven't yet converged
-    if(!stopits & verbose) report(convergence, ntokens=ntokens, beta, vocab, 
+    if(!stopits & verbose) report(convergence, ntokens=ntokens, beta, vocab,
                                        settings$topicreportevery, verbose)
   }
   #######
@@ -172,16 +183,20 @@ stm.control <- function(documents, vocab, settings, model=NULL) {
   beta$beta <- NULL
   lambda <- cbind(lambda,0)
   model <- list(mu=mu, sigma=sigma, beta=beta, settings=settings,
-                vocab=vocab, convergence=convergence, 
-                theta=exp(lambda - row.lse(lambda)), 
+                vocab=vocab, convergence=convergence,
+                theta=exp(lambda - log(rowSums(exp(lambda)))),
+                #note altered from row.lse above because of a
+                #Windows specific bug that was happening with
+                #matrixStats package and large matrices 8/27
                 eta=lambda[,-ncol(lambda), drop=FALSE],
                 invsigma=solve(sigma), time=time, version=utils::packageDescription("stm")$Version)
-  class(model) <- "STM"  
+  
+  class(model) <- "STM"
   return(model)
 }
 
 
 
-    
+
 
 
